@@ -429,8 +429,8 @@ side-by-side."
     (setq progress-glyph-height 24)
     (setq progress-layout-instantiator
 	  `[layout 
-	    :orientation vertical :justify left
-	    :margin-width 4
+	    :orientation vertical :margin-width 4
+	    :horizontally-justify left :vertically-justify center
 	    :items (,progress-text-instantiator
 		    [layout 
 		     :orientation horizontal
@@ -447,7 +447,8 @@ side-by-side."
 
 (defun set-progress-abort-instantiator (&optional locale)
   (set-glyph-image progress-abort-glyph
-		   `[layout :orientation vertical :justify left
+		   `[layout :orientation vertical
+			    :horizontally-justify left :vertically-justify center
 			    :items (,progress-text-instantiator
 				    [layout
 				     :margin-width 4
